use crate::{Card, Category, Component};

#[derive(Clone)]
pub struct Builder {
    data:Card,
}
impl Builder {
    pub fn new(card:Card) -> Self { Self { data:card } }
    pub fn build(self) -> Card { self.data }

    pub fn category (mut self, category:Category) -> Self { self.data.category = category; self }
    pub fn name     (mut self, name:&str)         -> Self { self.data.name = name.to_string(); self }
    pub fn cost     (mut self, cost:u8)           -> Self { self.data.cost = cost; self }
    pub fn payload  (mut self, payload:u8)        -> Self { self.data.payload = payload; self }
    pub fn labels   (mut self, labels:&[usize])   -> Self { self.data.labels = labels.to_vec(); self }

    pub fn concealed (mut self)   -> Self { self.data.concealed = true; self }

    pub fn component (mut self, page:usize, component:Component) -> Self
    {
        let (x, y) = (component.x, component.y);
        if self.data.add_component(page, component).is_err() {
            println!("error: failed to add component at ({}, {}).", x, y);
        }
        self
    }
}
