use crate::{statics::*, Card, Category, Component, Format};

pub fn generate_cards() -> Vec<Card>
{
    vec![
        // ----------- //
        //   Weapons   //
        // ----------- //

        // Automatic Rifle
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("Automatic Rifle")
        .payload(1)
        .cost(2)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Ballistic").at(0, 0).scale(4, 1))
        .component(PAGE_FRONT, Component::range(0, 3, 5, 9, 18, false).at(0, 1))
        .component(PAGE_FRONT, Component::ammo_use(Some(AC_AR6), 1, 0).at(0, 3))
        .component(PAGE_FRONT, Component::health(None, &[("★", 2)]).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_IRS, Some(HPS_OP), 4, None, false)
            .hardpoint(HP_IRS, Some(HPS_UN), 4, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_GM, None, 2, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("IRS #2", Some(0)),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("IRS #1", Some(4)),
            ("IRS #1", Some(0)),
        ]))
        .build(),

        // Submachine Gun
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("Submachine Gun")
        .payload(1)
        .cost(1)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Ballistic").at(0, 0).scale(4, 1))
        .component(PAGE_FRONT, Component::range(0, 2, 4, 6, 12, false).at(0, 1))
        .component(PAGE_FRONT, Component::ammo_use(Some(AC_HG9), 5, 0).at(0, 3))
        .component(PAGE_FRONT, Component::health(None, &[("★", 1)]).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_IRS, Some(HPS_OP), 3, None, false)
            .hardpoint(HP_IRS, None, 1, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_GM, None, 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("IRS #2", Some(0)),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("IRS #1", Some(0)),
        ]))
        .build(),

        // Shotgun
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("Shotgun")
        .payload(1)
        .cost(1)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Ballistic").at(0, 0).scale(4, 1))
        .component(PAGE_FRONT, Component::range(0, 2, 6, 0, 6, false).at(0, 1))
        .component(PAGE_FRONT, Component::ammo_use(Some(AC_BS2), 1, 1).at(0, 3))
        .component(PAGE_FRONT, Component::health(None, &[("★", 2)]).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_IRS, Some(HPS_OP), 2, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_GM, None, 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("IRS #1", Some(0)),
        ]))
        .build(),

        // Automatic Shotgun
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("Automatic Shotgun")
        .payload(1)
        .cost(2)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Ballistic").at(0, 0).scale(4, 1))
        .component(PAGE_FRONT, Component::range(0, 1, 3, 5, 5, false).at(0, 1))
        .component(PAGE_FRONT, Component::ammo_use(Some(AC_BS2), 2, 0).at(0, 3))
        .component(PAGE_FRONT, Component::health(None, &[("★", 2)]).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_IRS, Some(HPS_OP), 2, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_GM, None, 2, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("IRS #1", Some(0)),
        ]))
        .build(),

        // Marksman Rifle
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("Marksman Rifle")
        .payload(1)
        .cost(3)
        .component(PAGE_FRONT, Component::health(None, &[("★", 1)]).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Ballistic").at(0, 0).scale(4, 1))
        .component(PAGE_FRONT, Component::range(0, 4, 6, 10, 20, false).at(0, 1))
        .component(PAGE_FRONT, Component::ammo_use(Some(AC_AR6), 1, 1).at(0, 3))
        .component(PAGE_FRONT, Component::ammo(Some(AC_AR6), 8).at(0, 5).scale(2, 2))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_IRS, Some(HPS_OP), 4, None, false)
            .hardpoint(HP_IRS, Some(HPS_UN), 1, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_GM, None, 2, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("IRS #2", Some(0)),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("IRS #1", Some(4)),
            ("IRS #1", Some(0)),
        ]))
        .build(),

        // Precision Rifle
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("Precision Rifle")
        .payload(1)
        .cost(4)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Ballistic").at(0, 0).scale(4, 1))
        .component(PAGE_FRONT, Component::range(0, 4, 8, 12, 24, false).at(0, 1))
        .component(PAGE_FRONT, Component::ammo_use(Some(AC_AR8), 1, 1).at(0, 3))
        .component(PAGE_FRONT, Component::health(None, &[("★", 1)]).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_IRS, Some(HPS_OP), 6, None, false)
            .hardpoint(HP_IRS, Some(HPS_UN), 1, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_GM, None, 2, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("IRS #2", Some(0)),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("IRS #1", Some(4)),
            ("IRS #1", Some(0)),
        ]))
        .build(),

        // Anti-Material Rifle
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("Anti-Material Rifle")
        .payload(2)
        .cost(5)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Ballistic").at(0, 0).scale(4, 1))
        .component(PAGE_FRONT, Component::range(0, 3, 6, 12, 24, false).at(0, 1))
        .component(PAGE_FRONT, Component::ammo_use(Some(AC_AM12), 1, 1).at(0, 3))
        .component(PAGE_FRONT, Component::health(None, &[("★", 3)]).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_IRS, Some(HPS_OP), 6, None, false)
            .hardpoint(HP_IRS, Some(HPS_UN), 1, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_GM, None, 3, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("IRS #1", Some(0)),
        ]))
        .build(),

        // Light Machine Gun
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("Light Machine Gun")
        .payload(2)
        .cost(4)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Ballistic").at(0, 0).scale(4, 1))
        .component(PAGE_FRONT, Component::range(0, 3, 4, 8, 15, false).at(0, 1))
        .component(PAGE_FRONT, Component::ammo_use(Some(AC_AR6), 3, 0).at(0, 3))
        .component(PAGE_FRONT, Component::health(None, &[("★", 2)]).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_IRS, Some(HPS_OP), 3, None, false)
            .hardpoint(HP_IRS, Some(HPS_UN), 2, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_GM, None, 3, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("IRS #1", Some(0)),
        ]))
        .build(),

        // Machine Gun
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("Machine Gun")
        .payload(3)
        .cost(4)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Ballistic").at(0, 0).scale(4, 1))
        .component(PAGE_FRONT, Component::range(0, 3, 5, 10, 18, false).at(0, 1))
        .component(PAGE_FRONT, Component::ammo_use(Some(AC_AR8), 3, 0).at(0, 3))
        .component(PAGE_FRONT, Component::health(None, &[("★", 3)]).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_IRS, Some(HPS_OP), 3, None, false)
            .hardpoint(HP_IRS, Some(HPS_UN), 2, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_GM, None, 3, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("IRS #1", Some(0)),
        ]))
        .build(),

        // Heavy Machine Gun
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("Heavy Machine Gun")
        .payload(3)
        .cost(6)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Ballistic").at(0, 0).scale(4, 1))
        .component(PAGE_FRONT, Component::range(0, 3, 6, 10, 20, false).at(0, 1))
        .component(PAGE_FRONT, Component::ammo_use(Some(AC_AM12), 2, 0).at(0, 3))
        .component(PAGE_FRONT, Component::health(None, &[("★", 3)]).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_IRS, Some(HPS_OP), 3, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_GM, None, 4, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("IRS #1", Some(0)),
        ]))
        .build(),

        // Rocket 1E
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("Rocket 1E")
        .payload(1)
        .cost(1)
        .labels(&[LB_EXPLOSIVE])
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Rocket").at(0, 0).scale(4, 1))
        .component(PAGE_FRONT, Component::range(0, 3, 6, 9, 12, false).at(0, 1))
        .component(PAGE_FRONT, Component::damage(1, 0, 4, false).at(0, 3))
        .component(PAGE_FRONT, Component::cell().at(3, 3).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(None, 1).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT, Component::health(None, &[("★", 1)]).at(0, 9).scale(2, 1))
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_GM, None, 2, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Ammo", None),
            ("Ammo", None),
            ("Ammo", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("Ammo", None),
            ("Ammo", None),
            ("Ammo", None),
        ]))
        .build(),

        // Rocket 4E
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("Rocket 4E")
        .payload(2)
        .cost(5)
        .labels(&[LB_EXPLOSIVE])
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Rocket").at(0, 0).scale(4, 1))
        .component(PAGE_FRONT, Component::range(0, 3, 5, 8, 10, false).at(0, 1))
        .component(PAGE_FRONT, Component::damage(1, 0, 4, false).at(0, 3))
        .component(PAGE_FRONT, Component::cell().at(3, 3).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(None, 4).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT, Component::health(None, &[("★", 2)]).at(0, 9).scale(2, 1))
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_GM, None, 3, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Ammo", None),
            ("Ammo", None),
            ("Ammo", None),
            ("Ammo", None),
            ("", None),
            ("", None),
            ("", None),
            ("Ammo", None),
            ("Ammo", None),
            ("Ammo", None),
            ("Ammo", None),
        ]))
        .build(),

        // Recoilless Rifle 90
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("Recoilless Rifle 90")
        .payload(2)
        .cost(5)
        .labels(&[LB_VEHICLE])
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Ballistic").at(0, 0).scale(4, 1))
        .component(PAGE_FRONT, Component::range(0, 4, 8, 12, 18, false).at(0, 1))
        .component(PAGE_FRONT, Component::ammo_use(Some(AC_SH90), 1, 1).at(0, 3))
        .component(PAGE_FRONT, Component::health(Some(0), &[("★", 2)]).at(0, 9).scale(2, 1))
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_GM, None, 3, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Ammo", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("Ammo", None),
        ]))
        .build(),

        // Autocannon 20
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("Autocannon 20")
        .payload(4)
        .cost(8)
        .labels(&[LB_VEHICLE])
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Ballistic").at(0, 0).scale(4, 1))
        .component(PAGE_FRONT, Component::range(0, 4, 8, 10, 20, false).at(0, 1))
        .component(PAGE_FRONT, Component::ammo_use(Some(AC_AC20), 2, 0).at(0, 3))
        .component(PAGE_FRONT, Component::armor(Some(1), &[("★", 2)]).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT, Component::health(Some(0), &[("★", 3)]).at(0, 9).scale(2, 1))
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_GM, None, 5, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Ammo", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("Ammo", None),
        ]))
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Weapon)
        .name("RESERVED")
        .cost(0)
        .build(),


        // ------------- //
        //   Equipment   //
        // ------------- //

        // Reflex Sight
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("Reflex Sight")
        .payload(1)
        .cost(1)
        .labels(&[LB_INFANTRY])
        .component(PAGE_FRONT, Component::range(0, 2, 0, 0, 0, true).at(0, 0))
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_IRS, Some(HPS_OP), 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // Telescopic Sight x4
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("Telescopic Sight x4")
        .payload(1)
        .cost(2)
        .labels(&[LB_INFANTRY])
        .component(PAGE_FRONT, Component::range(0, 1, 1, 1, 0, true).at(0, 0))
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_IRS, Some(HPS_OP), 2, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // Telescopic Sight x8
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("Telescopic Sight x8")
        .payload(1)
        .cost(3)
        .labels(&[LB_INFANTRY])
        .component(PAGE_FRONT, Component::range(0, -2, 2, 4, 0, true).at(0, 0))
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_IRS, Some(HPS_OP), 3, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // Telescopic Sight x12
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("Telescopic Sight x12")
        .payload(1)
        .cost(4)
        .labels(&[LB_INFANTRY])
        .component(PAGE_FRONT, Component::range(0, -4, 4, 6, 0, true).at(0, 0))
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_IRS, Some(HPS_OP), 5, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // Laser Sight
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("Laser Sight")
        .payload(1)
        .cost(1)
        .component(PAGE_FRONT, Component::range(0, 1, 0, 0, 0, true).at(0, 0))
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_IRS, None, 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // Bipod
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("Bipod")
        .payload(1)
        .cost(1)
        .labels(&[LB_INFANTRY])
        .component(PAGE_FRONT, Component::field(LANG_TN, "-1").at(0, 0))
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_IRS, Some(HPS_UN), 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // Body Armor
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("Body Armor")
        .payload(1)
        .cost(1)
        .labels(&[LB_INFANTRY])
        .component(PAGE_FRONT, Component::armor(None, &[("★", 1)]).at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::text("Apply armor to equipping unit.").at(0, 8).scale(5, 2))
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_VST, None, 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // Digital Optic 2A
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("Digital Optic 2A")
        .payload(1)
        .cost(2)
        .labels(&[LB_VEHICLE])
        .component(PAGE_FRONT, Component::range(0, 1, 1, 0, 0, true).at(0, 0))
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_DI, None, 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // Digital Optic 6A
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("Digital Optic 6A")
        .payload(1)
        .cost(4)
        .labels(&[LB_VEHICLE])
        .component(PAGE_FRONT, Component::range(0, 1, 2, 2, 0, true).at(0, 0))
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_DI, None, 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // Digital Optic 12A
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("Digital Optic 12A")
        .payload(1)
        .cost(6)
        .labels(&[LB_VEHICLE])
        .component(PAGE_FRONT, Component::range(0, 2, 4, 6, 0, true).at(0, 0))
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_DI, None, 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // Ballistics Module
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("Ballistics Module")
        .payload(1)
        .cost(7)
        .labels(&[LB_VEHICLE])
        .component(PAGE_FRONT, Component::range(0, 0, 0, 2, 4, true).at(0, 0))
        .component(PAGE_FRONT, Component::field(LANG_TN, "-1").at(0, 2))
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_DI, None, 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Equipment)
        .name("RESERVED")
        .cost(0)
        .build(),


        // -------------- //
        //   Ammunition   //
        // -------------- //

        // Magazine, HG-9
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Magazine, HG-9")
        .payload(1)
        .cost(1)
        .component(PAGE_FRONT, Component::damage(0, 0, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_HG9), 5).at(0, 9).scale(2, 2))
        .build(),

        // Magazine, HG-9 HP
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Magazine, HG-9 HP")
        .payload(1)
        .cost(2)
        .component(PAGE_FRONT, Component::damage(1, -1, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_HG9), 5).at(0, 9).scale(2, 2))
        .build(),

        // Magazine, HG-9 AP
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Magazine, HG-9 AP")
        .payload(1)
        .cost(2)
        .component(PAGE_FRONT, Component::damage(0, 1, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_HG9), 5).at(0, 9).scale(2, 2))
        .build(),

        // Magazine, AR-6
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Magazine, AR-6")
        .payload(1)
        .cost(1)
        .component(PAGE_FRONT, Component::damage(1, 0, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_AR6), 8).at(0, 9).scale(2, 2))
        .build(),

        // Magazine, AR-6 HP
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Magazine, AR-6 HP")
        .payload(1)
        .cost(2)
        .component(PAGE_FRONT, Component::damage(2, -2, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_AR6), 8).at(0, 9).scale(2, 2))
        .build(),

        // Magazine, AR-6 AP
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Magazine, AR-6 AP")
        .payload(1)
        .cost(2)
        .component(PAGE_FRONT, Component::damage(1, 1, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_AR6), 8).at(0, 9).scale(2, 2))
        .build(),

        // Magazine, AR-6 T
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Magazine, AR-6 T")
        .payload(1)
        .cost(2)
        .component(PAGE_FRONT, Component::damage(1, 0, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::field(LANG_TN, "-1").at(3, 0))
        .component(PAGE_FRONT, Component::field(LANG_VISIBILITY, "+1").at(3, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_AR6), 8).at(0, 9).scale(2, 2))
        .build(),
        
        // Box, AR-6
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Box, AR-6")
        .payload(2)
        .cost(2)
        .component(PAGE_FRONT, Component::damage(1, 0, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_AR6), 16).at(0, 8).scale(2, 3))
        .build(),

        // Magazine, AR-8
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Magazine, AR-8")
        .payload(1)
        .cost(1)
        .component(PAGE_FRONT, Component::damage(2, 0, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_AR8), 6).at(0, 9).scale(2, 2))
        .build(),

        // Box, AR-8
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Box, AR-8")
        .payload(2)
        .cost(3)
        .component(PAGE_FRONT, Component::damage(2, 0, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_AR8), 12).at(0, 8).scale(2, 3))
        .build(),

        // Magazine, BS-2
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Magazine, BS-2")
        .payload(1)
        .cost(1)
        .component(PAGE_FRONT, Component::damage(1, 0, 2, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_BS2), 6).at(0, 9).scale(2, 2))
        .build(),

        // Magazine, BS-2 H
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Magazine, BS-2 H")
        .payload(1)
        .cost(2)
        .component(PAGE_FRONT, Component::damage(0, 0, 4, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_BS2), 6).at(0, 9).scale(2, 2))
        .build(),

        // Magazine, BS-2 AP
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Magazine, BS-2 AP")
        .payload(1)
        .cost(2)
        .component(PAGE_FRONT, Component::damage(1, 1, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_BS2), 6).at(0, 9).scale(2, 2))
        .build(),

        // Magazine, AM-12
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Magazine, AM-12")
        .payload(1)
        .cost(2)
        .component(PAGE_FRONT, Component::damage(2, 1, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_AM12), 4).at(0, 9).scale(2, 2))
        .build(),

        // Magazine, AM-12 AP
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Magazine, AM-12")
        .payload(1)
        .cost(3)
        .component(PAGE_FRONT, Component::damage(2, 2, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_AM12), 4).at(0, 9).scale(2, 2))
        .build(),

        // Box, AM-12
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Box, AM-12")
        .payload(2)
        .cost(5)
        .component(PAGE_FRONT, Component::damage(2, 1, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_AM12), 10).at(0, 9).scale(2, 2))
        .build(),

        // Magazine, AC-20
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Magazine, AC-20")
        .payload(2)
        .cost(5)
        .component(PAGE_FRONT, Component::damage(3, 1, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_AM12), 6).at(0, 9).scale(2, 2))
        .build(),

        // Shell, SH-90
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Shell, SH-90")
        .payload(1)
        .cost(2)
        .component(PAGE_FRONT, Component::damage(1, 4, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_SH90), 1).at(0, 9).scale(2, 2))
        .build(),

        // Magazine, SH-90
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("Magazine, SH-90")
        .payload(2)
        .cost(5)
        .component(PAGE_FRONT, Component::damage(1, 4, 0, false).at(0, 0))
        .component(PAGE_FRONT, Component::cell().at(3, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::ammo(Some(AC_SH90), 3).at(0, 9).scale(2, 2))
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Ammunition)
        .name("RESERVED")
        .cost(0)
        .build(),


        // ------------ //
        //   Upgrades   //
        // ------------ //

        // Specialist
        Card::builder(Format::Single)
        .category(Category::Upgrade)
        .name("Specialist")
        .cost(5)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Operator").at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::field(LANG_TN, "-1").at(0, 1).scale(1, 1))
        .build(),

        // Expert
        Card::builder(Format::Single)
        .category(Category::Upgrade)
        .name("Expert")
        .cost(10)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Operator").at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::field(LANG_TN, "-2").at(0, 1).scale(1, 1))
        .build(),

        // Mobile
        Card::builder(Format::Single)
        .category(Category::Upgrade)
        .name("Mobile")
        .cost(4)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Operator").at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::field(LANG_INITIATIVE, "+2").at(0, 1))
        .component(PAGE_FRONT, Component::field(LANG_MOBILITY, "+1").at(0, 2))
        .build(),

        // Loaded
        Card::builder(Format::Single)
        .category(Category::Upgrade)
        .name("Loaded")
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Operator").at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::field(LANG_CARGO, "+2").at(0, 1))
        .component(PAGE_FRONT, Component::field(LANG_EMBARK, "+2").at(0, 2))
        .cost(4)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Upgrade)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Upgrade)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Upgrade)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Upgrade)
        .name("RESERVED")
        .cost(0)
        .build(),


        // ------------- //
        //   Structure   //
        // ------------- //

        // Gun Port
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("Gun Port")
        .payload(1)
        .cost(1)
        .labels(&[LB_CREW])
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_TR, None, 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Crew", None),
            ("Crew", None),
            ("Crew", None),
            ("Crew", None),
            ("Crew", None),
            ("Crew", None),
            ("Crew", None),
            ("Crew", None),
            ("Crew", None),
            ("Crew", None),
            ("Crew", None),
        ]))
        .build(),

        // Gun Mount, Light
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("Gun Mount, Light")
        .payload(2)
        .cost(2)
        .labels(&[LB_CREW])
        .component(PAGE_FRONT, Component::armor(None, &[("★", 1)]).at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::health(None, &[("★", 1)]).at(0, 1).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_GM, None, 3, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_TR, None, 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Internal", None),
            ("Unit", None),
            ("Unit", None),
            ("GM #1", Some(2)),
            ("", None),
            ("", None),
            ("", None),
            ("GM #1", Some(0)),
            ("Unit", None),
            ("Unit", None),
            ("Internal", None),
        ]))
        .build(),

        // Gun Mount, Heavy
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("Gun Mount, Heavy")
        .payload(3)
        .cost(3)
        .labels(&[LB_CREW])
        .component(PAGE_FRONT, Component::armor(None, &[("★", 2)]).at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::health(None, &[("★", 1)]).at(0, 1).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_GM, None, 4, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_TR, None, 2, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Internal", None),
            ("Unit", None),
            ("GM #1", Some(3)),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("GM #1", Some(0)),
            ("Unit", None),
            ("Internal", None),
        ]))
        .build(),

        // Weapon Station 1A
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("Weapon Station 1A")
        .payload(3)
        .cost(4)
        .component(PAGE_FRONT, Component::armor(None, &[("★", 1)]).at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::health(None, &[("★", 2)]).at(0, 1).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_GM, None, 4, None, false)
            .hardpoint(HP_DI, None, 1, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_TR, None, 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Internal", None),
            ("DI #1", Some(0)),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("GM #1", Some(3)),
            ("GM #1", Some(0)),
            ("Internal", None),
        ]))
        .build(),

        // Weapon Station 1T
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("Weapon Station 1T")
        .payload(3)
        .cost(5)
        .labels(&[LB_COAXIAL])
        .component(PAGE_FRONT, Component::armor(None, &[("★", 1)]).at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::health(None, &[("★", 2)]).at(0, 1).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_GM, None, 2, None, false)
            .hardpoint(HP_GM, None, 2, None, false)
            .hardpoint(HP_DI, None, 1, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_TR, None, 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Internal", None),
            ("GM #1", Some(0)),
            ("DI #1", Some(0)),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("GM #2", Some(0)),
            ("Internal", None),
        ]))
        .build(),

        // Weapon Station 2B
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("Weapon Station 2B")
        .payload(4)
        .cost(6)
        .component(PAGE_FRONT, Component::armor(None, &[("★", 2)]).at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::health(None, &[("★", 2)]).at(0, 1).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_GM, None, 3, None, true)
            .hardpoint(HP_GM, None, 2, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_TR, None, 2, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Internal", None),
            ("GM #2", Some(0)),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("GM #1", Some(2)),
            ("GM #1", Some(0)),
            ("Internal", None),
        ]))
        .build(),

        // Gun Turret 1K
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("Gun Turret 1K")
        .payload(5)
        .cost(7)
        .component(PAGE_FRONT, Component::armor(Some(1), &[("★", 2)]).at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::health(Some(0), &[("★", 3)]).at(0, 1).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_TR, None, 1, None, true)
            .hardpoint(HP_GM, None, 5, None, true)
            .hardpoint(HP_DI, None, 1, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_TR, None, 4, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Internal", None),
            ("DI #1", Some(0)),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("TR #1", Some(0)),
            ("GM #1", Some(3)),
            ("GM #1", Some(0)),
            ("Internal", None),
        ]))
        .build(),

        // Gun Turret 2M
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("Gun Turret 2M")
        .payload(5)
        .cost(8)
        .component(PAGE_FRONT, Component::armor(Some(1), &[("★", 2)]).at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::health(Some(0), &[("★", 2)]).at(0, 1).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_GM, None, 5, None, true)
            .hardpoint(HP_GM, None, 3, None, true)
            .hardpoint(HP_DI, None, 1, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_TR, None, 5, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Internal", None),
            ("GM #2", Some(0)),
            ("DI #1", Some(0)),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("GM #1", Some(3)),
            ("GM #1", Some(0)),
            ("Internal", None),
        ]))
        .build(),

        // Adapter, GM 4:2x2
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("Adapter, GM 4:2x2")
        .payload(2)
        .cost(3)
        .labels(&[LB_COAXIAL])
        .component(PAGE_FRONT, Component::health(None, &[("★", 1)]).at(0, 0).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_GM, None, 2, None, false)
            .hardpoint(HP_GM, None, 2, None, false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_GM, None, 4, None, false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("GM #1", None),
            ("GM #1", None),
            ("GM #1", None),
            ("GM #1", None),
            ("GM #1", None),
            ("", None),
            ("GM #2", None),
            ("GM #2", None),
            ("GM #2", None),
            ("GM #2", None),
            ("GM #2", None),
        ]))
        .build(),

        // Compartment
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("Compartment")
        .payload(2)
        .cost(4)
        .labels(&[LB_BLOWOUT])
        .component(PAGE_FRONT, Component::health(None, &[("★", 1)]).at(0, 0).scale(2, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_ANY, None, 0, Some('A'), false)
            .at(0, 9).scale(4, 1)
        )
        .component(PAGE_FRONT,
            Component::mount()
            .hardpoint(HP_ANY, None, 1, Some('A'), false)
            .at(0, 10).scale(4, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Slot #1", None),
            ("Slot #1", None),
            ("Slot #1", None),
            ("Slot #1", None),
            ("Slot #1", None),
            ("Slot #1", None),
            ("Slot #1", None),
            ("Slot #1", None),
            ("Slot #1", None),
            ("Slot #1", None),
            ("Slot #1", None),
        ]))
        .build(),
        
        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("RESERVED")
        .cost(0)
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Structure)
        .name("RESERVED")
        .cost(0)
        .build(),


        // --------- //
        //   Field   //
        // --------- //

        // Foxhole
        Card::builder(Format::Single)
        .category(Category::Field)
        .name("Foxhole")
        .cost(5)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Reinforcement").at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::field(LANG_BUILD, "2").at(3, 0))
        .component(PAGE_FRONT, Component::armor(Some(1), &[("★", 3)]).at(0, 1).scale(2, 1))
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Unit", Some(0)),
            ("Unit", Some(3)),
            ("Unit", Some(6)),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("Unit", Some(6)),
            ("Unit", Some(3)),
            ("Unit", Some(0)),
        ]))
        .build(),

        // Tripod, Light
        Card::builder(Format::Single)
        .category(Category::Field)
        .name("Tripod, Light")
        .cost(3)
        .labels(&[LB_CREW])
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Emplacement").at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::field(LANG_BUILD, "1").at(3, 0))
        .component(PAGE_FRONT, Component::field(LANG_TN, "-1").at(0, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_GM, None, 3, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // Tripod, Heavy
        Card::builder(Format::Single)
        .category(Category::Field)
        .name("Tripod, Heavy")
        .cost(3)
        .labels(&[LB_CREW])
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Emplacement").at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::field(LANG_BUILD, "2").at(3, 0))
        .component(PAGE_FRONT, Component::field(LANG_TN, "-2").at(0, 1))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_GM, None, 4, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // Mine Field, Anti-Personnel
        Card::builder(Format::Single)
        .category(Category::Field)
        .name("Mine Field, Anti-Personnel")
        .cost(5)
        .labels(&[LB_CONCEALED])
        .concealed()
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Ordnance").at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::field(LANG_BUILD, "3").at(3, 0))
        .component(PAGE_FRONT, Component::damage(1, 1, 0, false).at(0, 1))
        .component(PAGE_FRONT, Component::field(LANG_SAVE, "4").at(3, 1))
        .component(PAGE_FRONT, Component::field(LANG_CAP, "3").at(3, 2))
        .component(PAGE_FRONT, Component::text("<b>When a unit of Cap+ enters this tile:</b><br>Roll 1d6 for each Hit; for each roll less than Save, apply damage.").at(0, 9).scale(5, 2))
        .build(),

        // Mine Field, Anti-Vehicle
        Card::builder(Format::Single)
        .category(Category::Field)
        .name("Mine Field, Anti-Vehicle")
        .cost(7)
        .labels(&[LB_CONCEALED])
        .concealed()
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Ordnance").at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::field(LANG_BUILD, "2").at(3, 0))
        .component(PAGE_FRONT, Component::damage(2, 1, 0, false).at(0, 1))
        .component(PAGE_FRONT, Component::field(LANG_SAVE, "5").at(3, 1))
        .component(PAGE_FRONT, Component::field(LANG_CAP, "6").at(3, 2))
        .component(PAGE_FRONT, Component::text("<b>When a unit of Cap+ enters this tile:</b><br>Roll 1d6 for each Hit; for each roll less than Save, apply damage.").at(0, 9).scale(5, 2))
        .build(),

        // Sentry Turret, Light
        Card::builder(Format::Single)
        .category(Category::Field)
        .name("Sentry Turret, Light")
        .cost(5)
        .labels(&[LB_AUTO])
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Emplacement").at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::field(LANG_BUILD, "2").at(3, 0))
        .component(PAGE_FRONT, Component::field(LANG_INITIATIVE, "2").at(3, 1))
        .component(PAGE_FRONT, Component::field(LANG_TN, "5").at(3, 2))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_TR, None, 2, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // Sentry Turret, Medium
        Card::builder(Format::Single)
        .category(Category::Field)
        .name("Sentry Turret, Medium")
        .cost(7)
        .labels(&[LB_AUTO])
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Emplacement").at(0, 0).scale(2, 1))
        .component(PAGE_FRONT, Component::field(LANG_BUILD, "2").at(3, 0))
        .component(PAGE_FRONT, Component::field(LANG_INITIATIVE, "2").at(3, 1))
        .component(PAGE_FRONT, Component::field(LANG_TN, "5").at(3, 2))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_TR, None, 4, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // RESERVED
        Card::builder(Format::Single)
        .category(Category::Field)
        .name("RESERVED")
        .cost(0)
        .build(),


        // --------- //
        //   Units   //
        // --------- //

        // Rifle Squad
        Card::builder(Format::Double)
        .category(Category::Unit)
        .name("Rifle Squad")
        .payload(4)
        .cost(4)
        .labels(&[LB_RESILIENT])
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Infantry").at(0, 0).scale(3, 1))
        .component(PAGE_FRONT, Component::field(LANG_MODE, "Foot").at(0, 1).scale(3, 1))
        .component(PAGE_FRONT, Component::field(LANG_SIZE, "1").at(4, 0))
        .component(PAGE_FRONT, Component::field(LANG_CARGO, "4").at(4, 1))
        .component(PAGE_FRONT, Component::field(LANG_MOVE, "1").at(6, 0))
        .component(PAGE_FRONT, Component::field(LANG_MOBILITY, "3").at(6, 1))
        .component(PAGE_FRONT, Component::field(LANG_INITIATIVE, "12").at(8, 0))
        .component(PAGE_FRONT, Component::field(LANG_TN, "4").at(8, 1))
        .component(PAGE_FRONT, Component::cell().at(0, 2).scale(10, 1))
        .component(PAGE_FRONT, Component::health(None, &[("★", 4)]).at(0, 3).scale(2, 1))
        .component(PAGE_FRONT, Component::cell().at(0, 4).scale(1, 6))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_VST, None, 1, None, false)
            .hardpoint(HP_BPK, None, 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // Sniper Team
        Card::builder(Format::Double)
        .category(Category::Unit)
        .name("Sniper Team")
        .payload(2)
        .cost(6)
        .labels(&[LB_RESILIENT])
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Infantry").at(0, 0).scale(3, 1))
        .component(PAGE_FRONT, Component::field(LANG_MODE, "Foot").at(0, 1).scale(3, 1))
        .component(PAGE_FRONT, Component::field(LANG_SIZE, "1").at(4, 0))
        .component(PAGE_FRONT, Component::field(LANG_CARGO, "2").at(4, 1))
        .component(PAGE_FRONT, Component::field(LANG_MOVE, "2").at(6, 0))
        .component(PAGE_FRONT, Component::field(LANG_MOBILITY, "3").at(6, 1))
        .component(PAGE_FRONT, Component::field(LANG_INITIATIVE, "10").at(8, 0))
        .component(PAGE_FRONT, Component::field(LANG_TN, "3").at(8, 1))
        .component(PAGE_FRONT, Component::cell().at(0, 2).scale(10, 1))
        .component(PAGE_FRONT, Component::health(None, &[("★", 4)]).at(0, 3).scale(2, 1))
        .component(PAGE_FRONT, Component::cell().at(0, 4).scale(1, 6))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_VST, None, 1, None, false)
            .hardpoint(HP_BPK, None, 1, None, false)
            .at(0, 10).scale(4, 1)
        )
        .build(),

        // AMR-1 Armored Personnel Carrier
        Card::builder(Format::Double)
        .category(Category::Unit)
        .name("AMR-1 Armored Personnel Carrier")
        .payload(10)
        .cost(12)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Vehicle").at(0, 0).scale(3, 1))
        .component(PAGE_FRONT, Component::field(LANG_MODE, "Wheeled").at(0, 1).scale(3, 1))
        .component(PAGE_FRONT, Component::cell().at(0, 2))
        .component(PAGE_FRONT, Component::field(LANG_SIZE, "2").at(4, 0))
        .component(PAGE_FRONT, Component::field(LANG_CARGO, "6").at(4, 1))
        .component(PAGE_FRONT, Component::field(LANG_EMBARK, "6").at(4, 2))
        .component(PAGE_FRONT, Component::field(LANG_MOVE, "10").at(6, 0))
        .component(PAGE_FRONT, Component::field(LANG_MOBILITY, "1").at(6, 1))
        .component(PAGE_FRONT, Component::field(LANG_TOW, "8").at(6, 2))
        .component(PAGE_FRONT, Component::field(LANG_INITIATIVE, "5").at(8, 0))
        .component(PAGE_FRONT, Component::field(LANG_TN, "4").at(8, 1))
        .component(PAGE_FRONT, Component::cell().at(8, 2))
        .component(PAGE_FRONT, Component::cell().at(0, 3).scale(10, 1))
        .component(PAGE_FRONT, Component::armor(Some(1), &[("F", 4), ("B", 2), ("L", 2), ("R", 2)]).at(0, 4).scale(2, 1))
        .component(PAGE_FRONT, Component::health(Some(0), &[("★", 4)]).at(0, 5).scale(2, 1))
        .component(PAGE_FRONT, Component::criticals(&[(LANG_MOVE, 2), (LANG_SYSTEM, 2), (LANG_ENGINE, 1), (LANG_POWER, 1)]).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT, Component::cell().at(9, 8).scale(1, 1))
        .component(PAGE_FRONT, Component::cell().at(0, 6).scale(1, 2))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_TR, None, 2, None, true)
            .at(0, 10).scale(9, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Internal, Crit", None),
            ("Internal", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("TR #1", Some(2)),
            ("TR #1", Some(0)),
            ("Internal", None),
            ("Internal, Crit", None),
        ]))
        .component(PAGE_BACK, Component::rolltable("Critical Table", &[
            ("Power", None),
            ("Engine", None),
            ("Move", None),
            ("Cargo", None),
            ("System", None),
            ("System", None),
            ("System", None),
            ("Crew", None),
            ("Move", None),
            ("Engine", None),
            ("Disabled", None),
        ]).at(5, 0))
        .build(),

        // RHN-2 Armored Fighting Vehicle
        Card::builder(Format::Double)
        .category(Category::Unit)
        .name("RHN-2 Armored Fighting Vehicle")
        .payload(12)
        .cost(15)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Vehicle").at(0, 0).scale(3, 1))
        .component(PAGE_FRONT, Component::field(LANG_MODE, "Wheeled").at(0, 1).scale(3, 1))
        .component(PAGE_FRONT, Component::cell().at(0, 2))
        .component(PAGE_FRONT, Component::field(LANG_SIZE, "2").at(4, 0))
        .component(PAGE_FRONT, Component::field(LANG_CARGO, "4").at(4, 1))
        .component(PAGE_FRONT, Component::field(LANG_EMBARK, "2").at(4, 2))
        .component(PAGE_FRONT, Component::field(LANG_MOVE, "8").at(6, 0))
        .component(PAGE_FRONT, Component::field(LANG_MOBILITY, "1").at(6, 1))
        .component(PAGE_FRONT, Component::field(LANG_TOW, "6").at(6, 2))
        .component(PAGE_FRONT, Component::field(LANG_INITIATIVE, "5").at(8, 0))
        .component(PAGE_FRONT, Component::field(LANG_TN, "4").at(8, 1))
        .component(PAGE_FRONT, Component::cell().at(8, 2))
        .component(PAGE_FRONT, Component::cell().at(0, 3).scale(10, 1))
        .component(PAGE_FRONT, Component::armor(Some(2), &[("F", 4), ("B", 3), ("L", 3), ("R", 2)]).at(0, 4).scale(2, 1))
        .component(PAGE_FRONT, Component::health(Some(0), &[("★", 3)]).at(0, 5).scale(2, 1))
        .component(PAGE_FRONT, Component::criticals(&[(LANG_MOVE, 2), (LANG_SYSTEM, 2), (LANG_ENGINE, 1), (LANG_POWER, 1)]).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT, Component::cell().at(9, 8).scale(1, 1))
        .component(PAGE_FRONT, Component::cell().at(0, 6).scale(1, 2))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_TR, Some(HPS_T), 5, None, true)
            .at(0, 10).scale(9, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Internal, Crit", None),
            ("Internal", None),
            ("TR #1", Some(4)),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("TR #1", Some(2)),
            ("TR #1", Some(0)),
            ("Internal", None),
            ("Internal, Crit", None),
        ]))
        .component(PAGE_BACK, Component::rolltable("Critical Table", &[
            ("Power", None),
            ("Engine", None),
            ("Move", None),
            ("Cargo", None),
            ("System", None),
            ("System", None),
            ("System", None),
            ("Crew", None),
            ("Move", None),
            ("Engine", None),
            ("Disabled", None),
        ]).at(5, 0))
        .build(),

        /*

        // M152 Mobility Vehicle

        // M90 Cargo Truck

        // ?? Attack Helicopter
        Card::builder(Format::Double)
        .category(Category::Unit)
        .name("?? Attack Helicopter")
        .payload(12)
        .cost(15)
        .component(PAGE_FRONT, Component::field(LANG_CLASS, "Vehicle").at(0, 0).scale(3, 1))
        .component(PAGE_FRONT, Component::field(LANG_MODE, "Rotorcraft").at(0, 1).scale(3, 1))
        .component(PAGE_FRONT, Component::cell().at(0, 2))
        .component(PAGE_FRONT, Component::field(LANG_SIZE, "2").at(4, 0))
        .component(PAGE_FRONT, Component::field(LANG_CARGO, "2").at(4, 1))
        .component(PAGE_FRONT, Component::field(LANG_EMBARK, "0").at(4, 2))
        .component(PAGE_FRONT, Component::field(LANG_MOVE, "8").at(6, 0))
        .component(PAGE_FRONT, Component::field(LANG_MOBILITY, "1").at(6, 1))
        .component(PAGE_FRONT, Component::field(LANG_TOW, "6").at(6, 2))
        .component(PAGE_FRONT, Component::field(LANG_INITIATIVE, "5").at(8, 0))
        .component(PAGE_FRONT, Component::field(LANG_TN, "4").at(8, 1))
        .component(PAGE_FRONT, Component::cell().at(8, 2))
        .component(PAGE_FRONT, Component::cell().at(0, 3).scale(10, 1))
        .component(PAGE_FRONT, Component::armor(Some(2), &[("F", 4), ("B", 3), ("L", 3), ("R", 2)]).at(0, 4).scale(2, 1))
        .component(PAGE_FRONT, Component::health(Some(0), &[("★", 3)]).at(0, 5).scale(2, 1))
        .component(PAGE_FRONT, Component::criticals(&[(LANG_MOVE, 2), (LANG_SYSTEM, 2), (LANG_ENGINE, 1), (LANG_POWER, 1)]).at(0, 8).scale(2, 1))
        .component(PAGE_FRONT, Component::cell().at(9, 8).scale(1, 1))
        .component(PAGE_FRONT, Component::cell().at(0, 6).scale(1, 2))
        .component(PAGE_FRONT,
            Component::slots()
            .hardpoint(HP_TR, Some(HPS_T), 5, true)
            .at(0, 10).scale(9, 1)
        )
        .component(PAGE_BACK, Component::rolltable("Location Table", &[
            ("Internal, Crit", None),
            ("Internal", None),
            ("TR #1", Some(4)),
            ("", None),
            ("", None),
            ("", None),
            ("", None),
            ("TR #1", Some(2)),
            ("TR #1", Some(0)),
            ("Internal", None),
            ("Internal, Crit", None),
        ]))
        .component(PAGE_BACK, Component::rolltable("Critical Table", &[
            ("Power", None),
            ("Engine", None),
            ("Move", None),
            ("Cargo", None),
            ("System", None),
            ("System", None),
            ("System", None),
            ("Crew", None),
            ("Move", None),
            ("Engine", None),
            ("Disabled", None),
        ]).at(5, 0))
        .build(),
        */
    ]
}
